IoBuf

Trait IoBuf 

pub trait IoBuf: 'static {
    // Required method
    fn as_init(&self) -> &[u8] ;
}
A trait for immutable buffers.

The IoBuf trait is implemented by buffer types that can be passed to immutable completion-based IO operations, like writing its content to a file. This trait will only take initialized bytes of a buffer into account.

Required Methods

fn as_init(&self) -> &[u8]

Get the slice of initialized bytes.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types



impl IoBuf for [u8]



fn as_init(&self) -> &[u8]



impl IoBuf for str



fn as_init(&self) -> &[u8]



impl<B> IoBuf for &'static B
where B: IoBuf + ?Sized,



fn as_init(&self) -> &[u8]



impl<B> IoBuf for &'static mut B
where B: IoBuf + ?Sized,



fn as_init(&self) -> &[u8]



impl<const N: usize> IoBuf for [u8; N]



fn as_init(&self) -> &[u8]

Implementors



impl IoBuf for BorrowedBuf<'static, u8>

Available on crate feature read_buf only.


impl IoBuf for BufferRef



impl IoBuf for Bytes

Available on crate feature bytes only.


impl IoBuf for BytesMut

Available on crate feature bytes only.


impl IoBuf for Mmap

Available on crate feature memmap2 only.


impl IoBuf for MmapMut

Available on crate feature memmap2 only.


impl IoBuf for String



impl<A> IoBuf for Vec<u8, A>
where A: Allocator + 'static,



impl<B, A> IoBuf for Arc<B, A>
where B: IoBuf + ?Sized, A: Allocator + 'static,



impl<B, A> IoBuf for Box<B, A>
where B: IoBuf + ?Sized, A: Allocator + 'static,



impl<B, A> IoBuf for Rc<B, A>
where B: IoBuf + ?Sized, A: Allocator + 'static,



impl<T> IoBuf for Slice<T>
where T: IoBuf,



impl<T> IoBuf for Uninit<T>
where T: IoBuf,



impl<T> IoBuf for VectoredBufIter<T>
where T: IoVectoredBuf,



impl<const N: usize> IoBuf for AncillaryBuf<N>



impl<const N: usize> IoBuf for ArrayVec<u8, N>

Available on crate feature arrayvec only.


impl<const N: usize> IoBuf for SmallVec<[u8; N]>
where [u8; N]: Array<Item = u8>,

Available on crate feature smallvec only.